@@ -2,18 +2,28 @@
 import json
 from copy import deepcopy
 
+from django import forms
 from django.conf import settings
-from django.forms import Textarea
+from django.core.serializers.json import DjangoJSONEncoder
 from django.template.loader import render_to_string
+from django.templatetags.static import static
 from django.utils.safestring import mark_safe
 from django.utils.translation.trans_real import get_language
 
+from cms.utils.urlutils import static_with_version
+
 from . import settings as text_settings
 
 
-class TextEditorWidget(Textarea):
+# this path is changed automatically whenever you run `gulp bundle`
+PATH_TO_JS = 'djangocms_text_ckeditor/js/dist/bundle-45a646fecc.cms.ckeditor.min.js'
+
+
+class TextEditorWidget(forms.Textarea):
     def __init__(self, attrs=None, installed_plugins=None, pk=None,
-                 placeholder=None, plugin_language=None, configuration=None):
+                 placeholder=None, plugin_language=None, configuration=None,
+                 cancel_url=None, render_plugin_url=None, action_token=None,
+                 delete_on_cancel=False):
         """
         Create a widget for editing text + plugins.
 
@@ -28,6 +38,9 @@ class TextEditorWidget(Textarea):
             attrs.update({
                 'class': new_class.strip()
             })
+        attrs.update({
+            'data-ckeditor-basepath': text_settings.TEXT_CKEDITOR_BASE_PATH
+        })
         super(TextEditorWidget, self).__init__(attrs)
         self.installed_plugins = installed_plugins
         self.pk = pk
@@ -39,11 +52,27 @@ class TextEditorWidget(Textarea):
             self.configuration = conf
         else:
             self.configuration = text_settings.CKEDITOR_SETTINGS
+        self.cancel_url = cancel_url
+        self.render_plugin_url = render_plugin_url
+        self.action_token = action_token
+        self.delete_on_cancel = delete_on_cancel
 
-    def render_textarea(self, name, value, attrs=None):
-        return super(TextEditorWidget, self).render(name, value, attrs)
+    @property
+    def media(self):
+        return forms.Media(
+            css={
+                'all': ('djangocms_text_ckeditor/css/cms.ckeditor.css',)
+            },
+            js=(
+                static_with_version('cms/js/dist/bundle.admin.base.min.js'),
+                static(PATH_TO_JS),
+            )
+        )
 
-    def render_additions(self, name, value, attrs=None):
+    def render_textarea(self, name, value, attrs=None, renderer=None):
+        return super(TextEditorWidget, self).render(name, value, attrs, renderer)
+
+    def render_additions(self, name, value, attrs=None, renderer=None):
         # id attribute is always present when rendering a widget
         ckeditor_selector = attrs['id']
         language = get_language().split('-')[0]
@@ -59,23 +88,27 @@ class TextEditorWidget(Textarea):
         # value or fallback to HTMLField
         else:
             configuration['toolbar'] = configuration.get('toolbar', 'HTMLField')
+
+        config = json.dumps(configuration, cls=DjangoJSONEncoder)
         context = {
             'ckeditor_class': self.ckeditor_class,
             'ckeditor_selector': ckeditor_selector,
             'ckeditor_function': ckeditor_selector.replace('-', '_'),
             'name': name,
             'language': language,
-            'settings': language.join(json.dumps(configuration).split("{{ language }}")),
+            'settings': config.replace('{{ language }}', language),
             'STATIC_URL': settings.STATIC_URL,
             'CKEDITOR_BASEPATH': text_settings.TEXT_CKEDITOR_BASE_PATH,
             'installed_plugins': self.installed_plugins,
             'plugin_pk': self.pk,
             'plugin_language': self.plugin_language,
-            'placeholder': self.placeholder
+            'placeholder': self.placeholder,
+            'widget': self,
+            'renderer': renderer,
         }
         return mark_safe(render_to_string('cms/plugins/widgets/ckeditor.html', context))
 
-    def render(self, name, value, attrs=None):
+    def render(self, name, value, attrs=None, renderer=None):
         return (
-            self.render_textarea(name, value, attrs) + self.render_additions(name, value, attrs)
+            self.render_textarea(name, value, attrs) + self.render_additions(name, value, attrs, renderer)
         )
